@@ -233,6 +233,24 @@ def version():
     return version
 
 
+def oh_my_zsh_auto_title():
+    '''give warning and offer to fix DISABLE_AUTO_TITLE
+
+       see: https://github.com/robbyrussell/oh-my-zsh/pull/257
+    '''
+
+    if 'SHELL' in os.environ and 'zsh' in os.environ.get('SHELL'):
+        if os.path.exists(os.path.expanduser('~/.oh-my-zsh')):
+            # oh-my-zsh exists
+            if 'DISABLE_AUTO_TITLE' not in os.environ or os.environ.get('DISABLE_AUTO_TITLE') == "false":
+                print('Please set:\n\n'
+                      '\texport DISABLE_AUTO_TITLE = \'true\'\n\n'
+                      'in ~/.zshrc or where your zsh profile is stored.\n'
+                      'Remember the "export" at the beginning!\n\n'
+                      'Then create a new shell or type:\n\n'
+                      '\t$ source ~/.zshrc')
+
+
 # http://www.rfk.id.au/blog/entry/preparing-pyenchant-for-python-3/
 try:
     unicode = unicode
